@@ -170,6 +170,9 @@ sub data {
         my $talk = SReview::Talk->by_nonce($c->stash('nonce'));
 
         my $data = $talk->corrected_times;
+	$c->app->log->debug($talk->video_fragments);
+        $data->{filename} = $talk->relative_name . "." . $c->srconfig->get("preview_exten");
+        $data->{room} = $talk->room;
 
         $c->render(json => $data);
 }
